@@ -5,7 +5,7 @@ import (
 	"net/http"
 	"os"
 
-	"github.com/bugsnag/bugsnag-go"
+	"github.com/bugsnag/bugsnag-go/v2"
 )
 
 // Insert your API key
